@@ -1,5 +1,5 @@
 package Beam::Minion::Command::worker;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Command to run a Beam::Minion worker
 
 #pod =head1 SYNOPSIS
@@ -15,6 +15,30 @@ our $VERSION = '0.002';
 #pod Service jobs are added to the queue using the L<beam minion run
 #pod command|Beam::Minion::Command::run>.
 #pod
+#pod =head1 ARGUMENTS
+#pod
+#pod =head2 container
+#pod
+#pod The container of tasks for this worker to handle. This can be an absolute
+#pod path to a container file, a relative path from the current directory, or
+#pod a relative path from one of the directories in the C<BEAM_PATH> environment
+#pod variable (separated by C<:>).
+#pod
+#pod =head1 ENVIRONMENT
+#pod
+#pod =head2 BEAM_MINION
+#pod
+#pod This variable defines the shared database to coordinate the Minion workers. This
+#pod database is used to queue the job. This must be the same for all workers
+#pod and every job running.
+#pod
+#pod See L<Beam::Minion/Getting Started> for how to set this variable.
+#pod
+#pod =head2 BEAM_PATH
+#pod
+#pod This variable is a colon-separated list of directories to search for
+#pod containers.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod L<Beam::Minion>, L<Minion>
@@ -63,7 +87,7 @@ Beam::Minion::Command::worker - Command to run a Beam::Minion worker
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -78,6 +102,30 @@ will run any service inside.
 Service jobs are added to the queue using the L<beam minion run
 command|Beam::Minion::Command::run>.
 
+=head1 ARGUMENTS
+
+=head2 container
+
+The container of tasks for this worker to handle. This can be an absolute
+path to a container file, a relative path from the current directory, or
+a relative path from one of the directories in the C<BEAM_PATH> environment
+variable (separated by C<:>).
+
+=head1 ENVIRONMENT
+
+=head2 BEAM_MINION
+
+This variable defines the shared database to coordinate the Minion workers. This
+database is used to queue the job. This must be the same for all workers
+and every job running.
+
+See L<Beam::Minion/Getting Started> for how to set this variable.
+
+=head2 BEAM_PATH
+
+This variable is a colon-separated list of directories to search for
+containers.
+
 =head1 SEE ALSO
 
 L<Beam::Minion>, L<Minion>
