@@ -1,5 +1,5 @@
 package Beam::Minion::Util;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Utility functions for Beam::Minion
 
 #pod =head1 SYNOPSIS
@@ -62,6 +62,9 @@ our %BACKEND = (
 #pod =cut
 
 sub minion_init_args {
+    die "You must set the BEAM_MINION environment variable to the Minion database URL.\n"
+        . "See `perldoc Beam::Minion` for getting started instructions.\n"
+        unless $ENV{BEAM_MINION};
     my ( $backend, $url );
     if ( $ENV{BEAM_MINION} =~ /^[^+:]+\+/ ) {
         return split /\+/, $ENV{BEAM_MINION};
@@ -96,7 +99,7 @@ Beam::Minion::Util - Utility functions for Beam::Minion
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
